diff libpurple/core.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 7517e6289bc9
line wrap: on
line diff
--- a/libpurple/core.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/core.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @defgroup core Gaim Core
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -21,10 +21,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef _GAIM_CORE_H_
-#define _GAIM_CORE_H_
+#ifndef _PURPLE_CORE_H_
+#define _PURPLE_CORE_H_
 
-typedef struct GaimCore GaimCore;
+typedef struct PurpleCore PurpleCore;
 
 typedef struct
 {
@@ -33,84 +33,84 @@
 	void (*ui_init)(void);
 	void (*quit)(void);
 
-} GaimCoreUiOps;
+} PurpleCoreUiOps;
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /**
  * Initializes the core of gaim.
  *
  * This will setup preferences for all the core subsystems.
  *
  * @param ui The ID of the UI using the core. This should be a
  *           unique ID, registered with the gaim team.
  *
  * @return @c TRUE if successful, or @c FALSE otherwise.
  */
-gboolean gaim_core_init(const char *ui);
+gboolean purple_core_init(const char *ui);
 
 /**
  * Quits the core of gaim, which, depending on the UI, may quit the
  * application using the gaim core.
  */
-void gaim_core_quit(void);
+void purple_core_quit(void);
 
 /**
  * Calls gaim_core_quit().  This can be used as the function 
  * passed to gaim_timeout_add() when you want to shutdown Gaim 
  * in a specified amount of time.  When shutting down Gaim 
  * from a plugin, you must use this with a timeout value of 0: 
- *   gaim_timeout_add(0, gaim_core_quitcb, NULL);
+ *   purple_timeout_add(0, purple_core_quitcb, NULL);
  * This is ensures that code from your plugin is not being 
  * executed when gaim_core_quit() is called.  Otherwise you 
  * would get a core dump after gaim_core_quit() executes and 
  * control returns to your plugin because gaim_core_quit() frees 
  * all plugins.
  */
-gboolean gaim_core_quit_cb(gpointer unused);
+gboolean purple_core_quit_cb(gpointer unused);
 
 /**
  * Returns the version of the core library.
  *
  * @return The version of the core library.
  */
-const char *gaim_core_get_version(void);
+const char *purple_core_get_version(void);
 
 /**
  * Returns the ID of the UI that is using the core.
  *
  * @return The ID of the UI that is currently using the core.
  */
-const char *gaim_core_get_ui(void);
+const char *purple_core_get_ui(void);
 
 /**
  * Returns a handle to the gaim core.
  *
  * This is used for such things as signals.
  */
-GaimCore *gaim_get_core(void);
+PurpleCore *purple_get_core(void);
 
 /**
  * Sets the UI ops for the core.
  *
  * @param ops A UI ops structure for the core.
  */
-void gaim_core_set_ui_ops(GaimCoreUiOps *ops);
+void purple_core_set_ui_ops(PurpleCoreUiOps *ops);
 
 /**
  * Returns the UI ops for the core.
  *
  * @return The core's UI ops structure.
  */
-GaimCoreUiOps *gaim_core_get_ui_ops(void);
+PurpleCoreUiOps *purple_core_get_ui_ops(void);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* _GAIM_CORE_H_ */
+#endif /* _PURPLE_CORE_H_ */
 
 /*
@@ -1,9 +1,9 @@
 /**
- * @defgroup core Gaim Core
+ * @defgroup core Purple Core
  *
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -33,84 +33,84 @@
 
 /**
- * Initializes the core of gaim.
+ * Initializes the core of purple.
  *
  * This will setup preferences for all the core subsystems.
@@ -33,84 +33,84 @@
  *
  * @param ui The ID of the UI using the core. This should be a
- *           unique ID, registered with the gaim team.
+ *           unique ID, registered with the purple team.
  *
  * @return @c TRUE if successful, or @c FALSE otherwise.
@@ -33,84 +33,84 @@
 
 /**
- * Quits the core of gaim, which, depending on the UI, may quit the
- * application using the gaim core.
+ * Quits the core of purple, which, depending on the UI, may quit the
+ * application using the purple core.
  */
@@ -33,84 +33,84 @@
 
 /**
- * Calls gaim_core_quit().  This can be used as the function 
- * passed to gaim_timeout_add() when you want to shutdown Gaim 
- * in a specified amount of time.  When shutting down Gaim 
+ * Calls purple_core_quit().  This can be used as the function 
+ * passed to purple_timeout_add() when you want to shutdown Purple 
+ * in a specified amount of time.  When shutting down Purple 
  * from a plugin, you must use this with a timeout value of 0: 
@@ -33,84 +33,84 @@
  * This is ensures that code from your plugin is not being 
- * executed when gaim_core_quit() is called.  Otherwise you 
- * would get a core dump after gaim_core_quit() executes and 
- * control returns to your plugin because gaim_core_quit() frees 
+ * executed when purple_core_quit() is called.  Otherwise you 
+ * would get a core dump after purple_core_quit() executes and 
+ * control returns to your plugin because purple_core_quit() frees 
  * all plugins.
  */
@@ -33,84 +33,84 @@
 
 /**
- * Returns a handle to the gaim core.
+ * Returns a handle to the purple core.
  *
  * This is used for such things as signals.